@@ -1,18 +1,20 @@
-#  This file is part of PyBuilder
+#   -*- coding: utf-8 -*-
 #
-#  Copyright 2011-2014 PyBuilder Team
+#   This file is part of PyBuilder
 #
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
+#   Copyright 2011-2014 PyBuilder Team
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
 #
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 
 import os
 import string
@@ -163,7 +165,7 @@ def build_binary_distribution(project, logger):
 
     for command in commands:
         logger.debug("Executing distutils command %s", command)
-        with open(os.path.join(reports_dir, command), "w") as output_file:
+        with open(os.path.join(reports_dir, command.replace("/", "")), "w") as output_file:
             commands = [sys.executable, setup_script]
             commands.extend(command.split())
             process = subprocess.Popen(commands,
